<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Personnaliser Conky - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Lancement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Couleur0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Couleur1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Couleur2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Couleur3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Couleur4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Couleur5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Couleur6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Couleur7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Couleur8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Couleur9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="684"/>
        <source>Select Color</source>
        <translation>Sélectionner la couleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="790"/>
        <source>Permission Denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="791"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Impossible d’écrire dans le fichier : %1
Autorisations insuffisantes.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Write Error</source>
        <translation>Erreur d’écriture</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Cannot write to file: %1</source>
        <translation>Impossible d’écrire dans le fichier : %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Backup Config File</source>
        <translation>Fichier de configuration de la sauvegarde</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Voulez-vous conserver le fichier d’origine ?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="897"/>
        <source>Backed Up Config File</source>
        <translation>Fichier de configuration sauvegardé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="898"/>
        <source>The original configuration was backed up to %1</source>
        <translation>La configuration d’origine a été sauvegardée sur %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Backup Failed</source>
        <translation>Impossible de sauvegarder</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Failed to create a backup file.</source>
        <translation>Impossible de créer un fichier de sauvegarde.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Restore Failed</source>
        <translation>Impossible de restaurer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <source>Failed to restore from backup file.</source>
        <translation>Impossible d’effectuer la restauration à partir du fichier de sauvegarde.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Backup file does not exist.</source>
        <translation>Le fichier de sauvegarde n’existe pas.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1328"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1340"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1341"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
        <source>Top Middle</source>
        <translation>En haut au milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1343"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1344"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1345"/>
        <source>Bottom Middle</source>
        <translation>En bas au milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1346"/>
        <source>Middle Left</source>
        <translation>Au milieu à gauche</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
        <source>Middle Right</source>
        <translation>Au milieu à droite</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
        <source>Middle Middle</source>
        <translation>Milieu Milieu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
        <source>Horizontal Gap</source>
        <translation>Écart horizontal</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Distance horizontale par rapport au bord de la fenêtre (en pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1366"/>
        <source>Vertical Gap</source>
        <translation>Écart vertical</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1367"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Distance verticale par rapport au bord de la fenêtre (en pixels)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1379"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1382"/>
        <source>Desktop 1</source>
        <translation>Bureau 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1383"/>
        <source>All Desktops</source>
        <translation>Tous les bureaux</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1395"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1407"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>La largeur doit être supérieure à la taille du contenu de la fenêtre,
sinon ce paramètre n’aura aucun effet</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1411"/>
        <source>Minimum Width</source>
        <translation>Largeur minimale</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1426"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>La hauteur doit être supérieure à la taille du contenu de la fenêtre,
sinon ce paramètre n’aura aucun effet.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1428"/>
        <source>Minimum Height</source>
        <translation>Hauteur minimale</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1442"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Augmente la hauteur de la fenêtre en ajoutant des lignes vides à la fin du fichier de configuration Conky</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1443"/>
        <source>Height Padding</source>
        <translation>Marge intérieure en hauteur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1458"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1471"/>
        <source>Transparency Type</source>
        <translation>Type de transparence</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1476"/>
        <source>Opaque</source>
        <translation>Opaque</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1477"/>
        <source>Transparent</source>
        <translation>Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
        <source>Pseudo-Transparent</source>
        <translation>Pseudo-Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1479"/>
        <source>Semi-Transparent</source>
        <translation>Semi-Transparent</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Opacity (%)</source>
        <translation>Opacité (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Opacité de la fenêtre

0 = Complètement transparent, 100 = Complètement opaque</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Background Color</source>
        <translation>Couleur d’arrière-plan</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1504"/>
        <source>Choose Color</source>
        <translation>Choisir la couleur</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1524"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Si vous réglez le type sur « Transparent », toute la fenêtre deviendra transparente (y compris les images). Utilisez « Pseudo-transparent » si vous souhaitez que les images restent opaques.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Si vous réglez le type sur « pseudo-transparent », la fenêtre deviendra transparente, mais elle aura une ombre. Vous pouvez désactiver l’ombre en configurant votre gestionnaire de fenêtres.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1545"/>
        <source>Transparency</source>
        <translation>Transparence</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1556"/>
        <source>Date Format</source>
        <translation>Format de la date</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1559"/>
        <source>Day</source>
        <translation>Jour</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1561"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1572"/>
        <source>Long</source>
        <translation>Long</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1562"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1573"/>
        <source>Short</source>
        <translation>Court</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1563"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nom abrégé, p.ex ma pour mardi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1570"/>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1574"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nom abrégé, p.ex oct pour octobre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1593"/>
        <source>Time Format</source>
        <translation>Format de l’heure</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1600"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1605"/>
        <source>12 Hour</source>
        <translation>12 heures</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1606"/>
        <source>24 Hour</source>
        <translation>24 heures</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1621"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Date &amp;&amp; Heure</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1634"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1642"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1645"/>
        <source>WiFi Network</source>
        <translation>Réseau WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1648"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1651"/>
        <source>Wired LAN Network</source>
        <translation>Réseau local câblé</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1665"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1928"/>
        <source>Select Background Color</source>
        <translation>Sélectionner la couleur du fond d’écran</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Personnaliser</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Total : 0 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="595"/>
        <source>Total: %1 conkies</source>
        <translation>Total : %1 conkies</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Affichage : %1 sur %2 conkies</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="547"/>
        <source>No Conky Selected</source>
        <translation>Aucun Conky sélectionné</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="549"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Sélectionner un conky dans la liste pour voir son aperçu</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="568"/>
        <source>Preview image could not be loaded</source>
        <translation>L’image de prévisualisation n’a pas pu être chargée</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>No preview image available</source>
        <translation>Aucune image de prévisualisation disponible</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="57"/>
        <location filename="../src/mainwindow.cpp" line="829"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="249"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="247"/>
        <source>About...</source>
        <translation>À propos…</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="254"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="269"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="267"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>Loading Conky configurations...</source>
        <translation>Chargement des configurations Conky…</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>Configure conky search paths</source>
        <translation>Configurer les chemins de recherche de Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="191"/>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="193"/>
        <source>Refresh conky list</source>
        <translation>Rafraîchir la liste Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="195"/>
        <source>Start All</source>
        <translation>Tout démarrer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="197"/>
        <source>Start all enabled conkies</source>
        <translation>Démarrer tous les conkies activés</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="199"/>
        <source>Stop All</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="201"/>
        <source>Stop all running conkies</source>
        <translation>Arrêter tous les conkies en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="931"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Running</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <location filename="../src/mainwindow.cpp" line="969"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="209"/>
        <source>Search conky by name...</source>
        <translation>Rechercher Conky par le nom…</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="211"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Rechercher des conkies par leur nom (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="256"/>
        <source>Display help</source>
        <translation>Afficher l’aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <location filename="../src/mainwindow.cpp" line="608"/>
        <source>Copy Conky</source>
        <translation>Copier Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="478"/>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky Copied</source>
        <translation>Conky copié</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky a été copié dans votre répertoire personnel pour être modifié :
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Copy Failed</source>
        <translation>La copie a échoué</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="481"/>
        <location filename="../src/mainwindow.cpp" line="659"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Impossible de copier conky dans votre dossier personnel.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="543"/>
        <source>Delete Conky</source>
        <translation>Supprimer Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="657"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky a été copié dans votre dossier personnel pour que vous puissiez le personnaliser :
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Delete Successful</source>
        <translation>Suppression réussie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="183"/>
        <source>Previews</source>
        <translation>Aperçus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Generate preview images for conkies</source>
        <translation>Générer des images d’aperçu pour les conkies</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <location filename="../src/mainwindow.cpp" line="929"/>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filtrer les conkies par état de fonctionnement ou emplacement</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="428"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Enter a name for the copy:</source>
        <translation>Entrez un nom pour la copie :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="605"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Pour pouvoir modifier et enregistrer un conky, vous devez d’abord le copier dans ~/.conky, où vous disposez des droits d’accès nécessaires.
Entrez un nom pour la copie.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>Directory Exists</source>
        <translation>Le répertoire existe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Un conky nommé « %1 » existe déjà dans votre dossier personnel.
Voulez-vous le remplacer ?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>Edit Conky</source>
        <translation>Modifier Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Ce fichier conky est en lecture seule et nécessite des privilèges d’administrateur pour être modifié.
Voulez-vous le modifier avec des privilèges élevés ?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Êtes-vous sûr de vouloir supprimer le fichier conky :
%1

Cette action ne peut pas être annulée.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="576"/>
        <source>Conky file deleted successfully.</source>
        <translation>Fichier Conky supprimé avec succès.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Delete Failed</source>
        <translation>La suppression a échoué</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Impossible de supprimer le fichier conky :
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>Customize Conky</source>
        <translation>Personnaliser Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="667"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Ce fichier conky est en lecture seule et nécessite des privilèges d’administrateur pour être personnalisé.
Souhaitez-vous le personnaliser avec des privilèges élevés ?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Editor Error</source>
        <translation>Erreur de l’éditeur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="818"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Impossible de démarrer l’éditeur pour le fichier : %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="828"/>
        <source>About MX Conky</source>
        <translation>À propos de MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="830"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="831"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Interface graphique permettant de configurer Conky dans MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="836"/>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="837"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="859"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="890"/>
        <source>MX Conky Help</source>
        <translation>Aide MX Conky</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Générer un aperçu</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Générer des images d’aperçu pour</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Widget sélectionné</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Tous les widgets dont l’aperçu est manquant</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Tous les widgets (remplacer les images existantes)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Aucun conky n’est actuellement sélectionné</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Images de haute qualité (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Générer des images d’aperçu au format PNG au lieu du format JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Aucun élément</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Aucun widget Conky nécessite la génération d’un aperçu.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="155"/>
        <source>Starting preview generation...</source>
        <translation>Lancement de la génération de l’aperçu…</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="159"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="198"/>
        <source>Generating preview for: %1</source>
        <translation>Génération de l’aperçu pour : %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="419"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Génération de l’aperçu terminée ! %1 aperçus générés.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="423"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="426"/>
        <source>Preview Generation Complete</source>
        <translation>Génération de l’aperçu terminée</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>%1 images d’aperçu ont été générées avec succès.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Choix du fichier de configuration de conky-manager</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Vous devez exécuter ce programme en tant qu’utilisateur normal.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Sélectionner le répertoire Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>Paramètres MX Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Chemins de recherche</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Chemins de recherche Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Ajouter un chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Supprimer le chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Modifier le chemin</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Paramètres du démarrage automatique</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Démarrer Conky au démarrage du système</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Délai de démarrage (en secondes) :</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>Valider</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>